@@ -1,22 +1,45 @@
 package Email::Sender::Failure;
-our $VERSION = '0.091640_004';
+use Mouse;
 
-use Moose;
-# ABSTRACT: a report of failure from an email sending transport
+our $VERSION = '0.001';
 
 use overload '""' => sub { $_[0]->message }, fallback => 1;
 
+=head1 NAME
+
+Email::Sender::Failure - a report of failure from an email sending transport
+
+=head1 METHODS
+
+=head2 message
+
+This method returns the failure message, which should describe the failure.
+Failures stringify to this message.
+
+=cut
 
 has message => (
   is       => 'ro',
   required => 1,
 );
 
+=head2 code
+
+This returns the numeric code of the failure, if any.  This is mostly useful
+for network protocol transports like SMTP.  This may be undefined.
+
+=cut
 
 has code => (
   is => 'ro',
 );
 
+=head2 recipients
+
+This returns a list (or, in scalar context, an arrayref) of addresses to which
+the email could not be sent.
+
+=cut
 
 has _recipients => (
   is         => 'rw',
@@ -27,7 +50,6 @@ has _recipients => (
 
 sub recipients { shift->_recipients }
 
-
 sub throw {
   my $inv = shift;
   die $inv if ref $inv;
@@ -43,9 +65,6 @@ sub BUILD {
 sub BUILDARGS {
   my ($self, @args) = @_;
 
-  return {} unless @args;
-  return {} if @args == 1 and ! defined $args[0];
-
   if (@args == 1 and (!ref $args[0]) and defined $args[0] and length $args[0]) {
     return { message => $args[0] };
   }
@@ -53,26 +72,9 @@ sub BUILDARGS {
   return $self->SUPER::BUILDARGS(@args);
 }
 
-
-__PACKAGE__->meta->make_immutable;
-no Moose;
-1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Email::Sender::Failure - a report of failure from an email sending transport
-
-=head1 VERSION
-
-version 0.091640_004
-
 =head1 SEE ALSO
 
-=over 
+=over
 
 =item * L<Email::Sender::Permanent>
 
@@ -80,48 +82,10 @@ version 0.091640_004
 
 =item * L<Email::Sender::Multi>
 
-=back 
-
-=head1 ATTRIBUTES
-
-=head2 message
-
-This method returns the failure message, which should describe the failure.
-Failures stringify to this message.
-
-=head2 code
-
-This returns the numeric code of the failure, if any.  This is mostly useful
-for network protocol transports like SMTP.  This may be undefined.
-
-=head2 recipients
-
-This returns a list (or, in scalar context, an arrayref) of addresses to which
-the email could not be sent.
-
-=head1 METHODS
-
-=head2 throw
-
-This method can be used to instantiate and throw an Email::Sender::Failure
-object at once.
-
-  Email::Sender::Failure->throw(\%arg);
-
-Instead of a hashref of args, you can pass a single string argument which will
-be used as the C<message> of the new failure.
-
-=head1 AUTHOR
-
-  Ricardo Signes <rjbs@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Ricardo Signes.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+=back
 
+=cut
 
+__PACKAGE__->meta->make_immutable;
+no Mouse;
+1;
