@@ -1,9 +1,14 @@
 package Email::Sender::Transport::Maildir;
-our $VERSION = '0.091640_004';
+use Mouse;
+extends 'Email::Sender::Transport';
 
-use Moose;
-with 'Email::Sender::Transport';
-# ABSTRACT: deliver mail to a maildir on disk
+our $VERSION = '0.001';
+
+=head1 NAME
+
+Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
+
+=cut
 
 use Errno ();
 use Fcntl;
@@ -12,6 +17,21 @@ use File::Spec;
 
 use Sys::Hostname;
 
+=head1 DESCRIPTION
+
+This transport delivers into a maildir.  The maildir's location may be given as
+the F<dir> argument to the constructor, and defaults to F<Maildir> in the
+current directory (at the time of transport initialization).
+
+If the directory does not exist, it will be created.
+
+Three headers will be added:
+
+ * X-Email-Sender-From - the envelope sender
+ * X-Email-Sender-To   - the envelope recipients (one header per rcpt)
+ * Lines               - the number of lines in the body
+
+=cut
 
 my $HOSTNAME;
 BEGIN { ($HOSTNAME = hostname) =~ s/\..*//; }
@@ -114,46 +134,5 @@ sub _delivery_fh {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Mouse;
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
-
-=head1 VERSION
-
-version 0.091640_004
-
-=head1 DESCRIPTION
-
-This transport delivers into a maildir.  The maildir's location may be given as
-the F<dir> argument to the constructor, and defaults to F<Maildir> in the
-current directory (at the time of transport initialization).
-
-If the directory does not exist, it will be created.
-
-Three headers will be added:
-
- * X-Email-Sender-From - the envelope sender
- * X-Email-Sender-To   - the envelope recipients (one header per rcpt)
- * Lines               - the number of lines in the body
-
-=head1 AUTHOR
-
-  Ricardo Signes <rjbs@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Ricardo Signes.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
-
-
