@@ -1,92 +1,13 @@
 package Email::Sender::Transport::Sendmail;
-our $VERSION = '0.091640_004';
+use Mouse;
+extends 'Email::Sender::Transport';
 
-use Moose;
-with 'Email::Sender::Transport';
-# ABSTRACT: send mail via sendmail(1)
-
-
-use File::Spec ();
-
-has 'sendmail' => (
-  is  => 'ro',
-  isa => 'Str',
-  required => 1,
-  lazy     => 1,
-  default  => sub {
-    # This should not have to be lazy, but Moose has a bug(?) that prevents the
-    # instance or partial-instance from being passed in to the default sub.
-    # Laziness doesn't hurt much, though, because (ugh) of the BUILD below.
-    # -- rjbs, 2008-12-04
-
-    # return $ENV{PERL_SENDMAIL_PATH} if $ENV{PERL_SENDMAIL_PATH}; # ???
-    return $_[0]->_find_sendmail('sendmail');
-  },
-);
-
-sub BUILD {
-  $_[0]->sendmail; # force population -- rjbs, 2009-06-08
-}
-
-sub _find_sendmail {
-  my ($self, $program_name) = @_;
-  $program_name ||= 'sendmail';
-
-  for my $dir (File::Spec->path) {
-    my $sendmail = File::Spec->catfile($dir, $program_name);
-    return $sendmail if ($^O eq 'MSWin32') ? -f $sendmail : -x $sendmail;
-  }
-
-  Carp::confess("couldn't find a sendmail executable");
-}
-
-sub _sendmail_pipe {
-  my ($self, $envelope) = @_;
-
-  my $prog = $self->sendmail;
-
-  my ($first, @args) = $^O eq 'MSWin32'
-           ? qq(| "$prog" -f $envelope->{from} @{$envelope->{to}})
-           : (q{|-}, $prog, '-f', $envelope->{from}, @{$envelope->{to}});
-
-  no warnings 'exec'; ## no critic
-  my $pipe;
-  Email::Sender::Failure->throw("couldn't open pipe to sendmail ($prog): $!")
-    unless open($pipe, $first, @args);
-
-  return $pipe;
-}
-
-sub send_email {
-  my ($self, $email, $envelope) = @_;
-
-  my $pipe = $self->_sendmail_pipe($envelope);
-
-  print $pipe $email->as_string
-    or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
-
-  close $pipe
-    or Email::Sender::Failure->throw("error when closing pipe to sendmail: $!");
-
-  return $self->success;
-}
-
-__PACKAGE__->meta->make_immutable;
-no Moose;
-1;
-
-__END__
-
-=pod
+our $VERSION = '0.001';
 
 =head1 NAME
 
 Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
-=head1 VERSION
-
-version 0.091640_004
-
 =head2 DESCRIPTION
 
 This transport sends mail by piping it to the F<sendmail> command.  If the
@@ -98,17 +19,57 @@ To specify the location of sendmail:
 
   my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
 
-=head1 AUTHOR
+=cut
 
-  Ricardo Signes <rjbs@cpan.org>
+use File::Spec ();
 
-=head1 COPYRIGHT AND LICENSE
+has 'sendmail' => (
+  is  => 'ro',
+  isa => 'Str',
+  required => 1,
+  lazy     => 1,
+  default  => sub {
+    # This should not have to be lazy, but Mouse has a bug(?) that prevents the
+    # instance or partial-instance from being passed in to the default sub.
+    # Laziness doesn't hurt much, though, because (ugh) of the BUILD below.
+    # -- rjbs, 2008-12-04
 
-This software is copyright (c) 2009 by Ricardo Signes.
+    # return $ENV{PERL_SENDMAIL_PATH} if $ENV{PERL_SENDMAIL_PATH}; # ???
+    return $_[0]->_find_sendmail('sendmail');
+  },
+);
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+sub _find_sendmail {
+  my ($self, $program_name) = @_;
+  $program_name ||= 'sendmail';
 
-=cut 
+  for my $dir (File::Spec->path) {
+    my $sendmail = File::Spec->catfile($dir, $program_name);
+    return $sendmail if -x $sendmail;
+  }
 
+  Carp::confess("couldn't find a sendmail executable");
+}
 
+sub send_email {
+  my ($self, $email, $envelope) = @_;
+
+  my $sendmail = $self->sendmail;
+
+  # This isn't a problem; we die if it fails, anyway. -- rjbs, 2007-07-17
+  no warnings 'exec'; ## no critic
+  open my $pipe, q{|-}, ($sendmail, '-f', $envelope->{from}, @{$envelope->{to}})
+    or Email::Sender::Failure->throw("couldn't open pipe to sendmail: $!");
+
+  print $pipe $email->as_string
+    or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
+
+  close $pipe
+    or Email::Sender::Failure->throw("error when closing pipe to sendmail: $!");
+
+  return $self->success;
+}
+
+__PACKAGE__->meta->make_immutable;
+no Mouse;
+1;
