@@ -1,9 +1,8 @@
 use strict;
 use warnings;
 package Email::Sender::Util;
-our $VERSION = '0.091640_004';
 
-# ABSTRACT: random stuff that makes Email::Sender go
+our $VERSION = '0.001';
 
 use Email::Address;
 use Email::Sender::Failure;
@@ -11,6 +10,12 @@ use Email::Sender::Failure::Permanent;
 use Email::Sender::Failure::Temporary;
 use List::MoreUtils ();
 
+=head1 NAME
+
+Email::Sender::Util - random stuff that makes Email::Sender go
+
+=cut
+
 # This code will be used by Email::Sender::Simple. -- rjbs, 2008-12-04
 sub _recipients_from_email {
   my ($self, $email) = @_;
@@ -55,30 +60,3 @@ sub _failure {
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Email::Sender::Util - random stuff that makes Email::Sender go
-
-=head1 VERSION
-
-version 0.091640_004
-
-=head1 AUTHOR
-
-  Ricardo Signes <rjbs@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Ricardo Signes.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
-
-
